Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(907)

Unified Diff: content/browser/mojo/mojo_shell_client_host.h

Issue 1738663002: Hook embedded shell up to MojoShellConnection (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/mojo/mojo_shell_client_host.h
diff --git a/content/browser/mojo/mojo_shell_client_host.h b/content/browser/mojo/mojo_shell_client_host.h
index 8b945fa7a3d403af8c800f214ef895f6691466fd..6585d5847172bab7aff3f2698237120ffc4d7825 100644
--- a/content/browser/mojo/mojo_shell_client_host.h
+++ b/content/browser/mojo/mojo_shell_client_host.h
@@ -16,9 +16,10 @@ class RenderProcessHost;
// Creates a communication channel between the external Mojo shell and the
// child. The server handle of this channel is shared with the external shell
// via Mojo IPC. |child_process_id| is used to uniquify the child in the
// external shell's instance map.
void RegisterChildWithExternalShell(int child_process_id,
+ int instance_id,
RenderProcessHost* render_process_host);
// Returns the URL associated with an instance corresponding to the renderer
« no previous file with comments | « content/browser/child_process_security_policy_unittest.cc ('k') | content/browser/mojo/mojo_shell_client_host.cc » ('j') | no next file with comments »
@@ -16,9 +16,10 @@ class RenderProcessHost;
// Creates a communication channel between the external Mojo shell and the
// child. The server handle of this channel is shared with the external shell
-// via Mojo IPC. |child_process_id| is used to uniquify the child in the
-// external shell's instance map.
+// via Mojo IPC. |child_process_id| and |instance_id| are used to uniquify the
+// child in the external shell's instance map.
void RegisterChildWithExternalShell(int child_process_id,

Powered by Google App Engine
This is Rietveld 408576698